@@ -2,7 +2,7 @@ from typing import List
 import typer
 
 from rich import print
-from earthscope_cli.m2m import m2m_flow
+from earthscope_cli.m2m import CliClientCredentialsFlow
 from earthscope_cli.sso import device_flow
 from earthscope_sdk.user.user import get_user, lookup_anon
 
@@ -29,6 +29,7 @@ def lookup(
     ),
 ):
     try:
+        m2m_flow = CliClientCredentialsFlow.get()
         m2m_flow.load_tokens()
         resp = lookup_anon(m2m_flow.access_token, ids=ids, emails=emails)
         print(resp)
